summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libpng
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/3rdparty/libpng
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libpng')
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/CHANGES6
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/README6
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/Y2KINFO2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/example.c10
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/libpng.334
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/libpng.txt34
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/libpngpf.32
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/png.52
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/png.h20
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngconf.h2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngerror.c12
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pnggccrd.c6
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngmem.c10
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngread.c2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngrio.c4
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c16
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngrutil.c10
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngtest.c14
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngwio.c4
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngwrite.c2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c16
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/projects/msvc/README.txt2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/scripts/makefile.bd322
23 files changed, 109 insertions, 109 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/CHANGES b/tqtinterface/qt4/src/3rdparty/libpng/CHANGES
index 5f05e9f..939baeb 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/CHANGES
+++ b/tqtinterface/qt4/src/3rdparty/libpng/CHANGES
@@ -75,7 +75,7 @@ version 0.87 [January, 1996]
added some minor documentation
version 0.88 [January, 1996]
fixed progressive bugs
- tqreplaced tabs with spaces
+ replaced tabs with spaces
cleaned up documentation
added callbacks for read/write and warning/error functions
version 0.89 [July, 1996]
@@ -265,7 +265,7 @@ version 0.99h [March 6, 1998, evening]
version 1.00 [March 7, 1998]
Changed several typedefs in pngrutil.c
Added makefile.wat (Pawel Mrochen), updated makefile.tc3 (Willem van Schaik)
- tqreplaced "while(1)" with "for(;;)"
+ replaced "while(1)" with "for(;;)"
added PNGARG() to prototypes in pngtest.c and removed some prototypes
updated some of the makefiles (Tom Lane)
changed some typedefs (s_start, etc.) in pngrutil.c
@@ -573,7 +573,7 @@ version 1.0.5j [December 21, 1999]
Restored backward compatibility of tEXt/zTXt chunk processing:
Restored the first four members of png_text to the same order as v.1.0.5d.
Added members "lang_key" and "itxt_length" to png_text struct. Set
- text_length=0 when "text" tqcontains iTXt data. Use the "compression"
+ text_length=0 when "text" contains iTXt data. Use the "compression"
member to distinguish among tEXt/zTXt/iTXt types. Added
PNG_ITXT_COMPRESSION_NONE (1) and PNG_ITXT_COMPRESSION_zTXt(2) macros.
The "Note" above, about backward incompatibility of libpng-1.0.5e, no
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/README b/tqtinterface/qt4/src/3rdparty/libpng/README
index d7b6dd1..1991908 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/README
+++ b/tqtinterface/qt4/src/3rdparty/libpng/README
@@ -74,7 +74,7 @@ some images. You will definitely need zlib 1.0.4 or later if you are
taking advantage of the MS-DOS "far" structure allocation for the small
and medium memory models. You should also note that zlib is a
compression library that is useful for more things than just PNG files.
-You can use zlib as a drop-in tqreplacement for fread() and fwrite() if
+You can use zlib as a drop-in replacement for fread() and fwrite() if
you are so inclined.
zlib should be available at the same place that libpng is.
@@ -87,8 +87,8 @@ these resources you can try ftp.uu.net in the /graphics/png directory.
This code is currently being archived at ftp.uu.net in the
/graphics/png directory, and on CompuServe, Lib 20 (PNG SUPPORT)
-at GO GRAPHSUP. If you can't tqfind it in any of those places,
-e-mail me, and I'll help you tqfind it.
+at GO GRAPHSUP. If you can't find it in any of those places,
+e-mail me, and I'll help you find it.
If you have any code changes, requests, problems, etc., please e-mail
them to me. Also, I'd appreciate any make files or project files,
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/Y2KINFO b/tqtinterface/qt4/src/3rdparty/libpng/Y2KINFO
index f86ebd1..f57e962 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/Y2KINFO
+++ b/tqtinterface/qt4/src/3rdparty/libpng/Y2KINFO
@@ -46,7 +46,7 @@
The tIME chunk itself is also Y2K compliant. It uses a 2-byte unsigned
integer to hold the year, and can hold years as large as 65535.
- zlib, upon which libpng depends, is also Y2K compliant. It tqcontains
+ zlib, upon which libpng depends, is also Y2K compliant. It contains
no date-related code.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/example.c b/tqtinterface/qt4/src/3rdparty/libpng/example.c
index b39478a..c7ebb4b 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/example.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/example.c
@@ -138,7 +138,7 @@ void read_png(FILE *fp, unsigned int sig_read) /* file is already open */
png_init_io(png_ptr, fp);
#else no_streams /* PNG file I/O method 2 */
- /* If you are using tqreplacement read functions, instead of calling
+ /* If you are using replacement read functions, instead of calling
* png_init_io() here you would call:
*/
png_set_read_fn(png_ptr, (void *)user_io_ptr, user_read_fn);
@@ -488,14 +488,14 @@ row_callback(png_structp png_ptr, png_bytep new_row,
* this function will be called for every row in every pass.
*
* In this function you will receive a pointer to new row data from
- * libpng called new_row that is to tqreplace a corresponding row (of
+ * libpng called new_row that is to replace a corresponding row (of
* the same data format) in a buffer allocated by your application.
*
* The new row data pointer new_row may be NULL, indicating there is
- * no new data to be tqreplaced (in cases of interlace loading).
+ * no new data to be replaced (in cases of interlace loading).
*
* If new_row is not NULL then you need to call
- * png_progressive_combine_row() to tqreplace the corresponding row as
+ * png_progressive_combine_row() to replace the corresponding row as
* shown below:
*/
/* Check if row_num is in bounds. */
@@ -602,7 +602,7 @@ void write_png(char *file_name /* , ... other image information ... */)
/* set up the output control if you are using standard C streams */
png_init_io(png_ptr, fp);
#else no_streams /* I/O initialization method 2 */
- /* If you are using tqreplacement read functions, instead of calling
+ /* If you are using replacement read functions, instead of calling
* png_init_io() here you would call */
png_set_write_fn(png_ptr, (void *)user_io_ptr, user_write_fn,
user_IO_flush_function);
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/libpng.3 b/tqtinterface/qt4/src/3rdparty/libpng/libpng.3
index 2f89149..a0fc097 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/libpng.3
+++ b/tqtinterface/qt4/src/3rdparty/libpng/libpng.3
@@ -862,8 +862,8 @@ be found at the zlib home page, <http://www.info-zip.org/pub/infozip/zlib/>.
The zlib compression utility is a general purpose utility that is
useful for more than PNG files, and can be used without libpng.
See the documentation delivered with zlib for more details.
-You can usually tqfind the source files for the zlib utility wherever you
-tqfind the libpng source files.
+You can usually find the source files for the zlib utility wherever you
+find the libpng source files.
Libpng is thread safe, provided the threads are using different
instances of the structures. Each thread should have its own
@@ -932,7 +932,7 @@ with the number of bytes you read from the beginning. Libpng will
then only check the bytes (if any) that your program didn't read.
(*): If you are not using the standard I/O functions, you will need
-to tqreplace them with custom functions. See the discussion under
+to replace them with custom functions. See the discussion under
Customizing libpng.
@@ -1045,7 +1045,7 @@ input stream. You must supply the function
read_chunk_callback(png_ptr ptr,
png_unknown_chunkp chunk);
{
- /* The unknown chunk structure tqcontains your
+ /* The unknown chunk structure contains your
chunk data: */
png_byte name[5];
png_byte *data;
@@ -1697,7 +1697,7 @@ or as an RGB triplet that may or may not be in the palette (need_expand = 0).
The png_set_background() function tells libpng to composite images
with alpha or simple transparency against the supplied background
-color. If the PNG file tqcontains a bKGD chunk (PNG_INFO_bKGD valid),
+color. If the PNG file contains a bKGD chunk (PNG_INFO_bKGD valid),
you may use this color, or supply another color more suitable for
the current display (e.g., the background color from a web page). You
need to tell libpng whether the color is in the gamma space of the
@@ -1761,7 +1761,7 @@ recommended that PNG viewers support gamma correction.
If you need to reduce an RGB file to a paletted file, or if a paletted
file has more entries then will fit on your screen, png_set_dither()
will do that. Note that this is a simple match dither that merely
-tqfinds the closest color available. This should work fairly well with
+finds the closest color available. This should work fairly well with
optimized palettes, and fairly badly with linear color cubes. If you
pass a palette that is larger then maximum_colors, the file will
reduce the number of colors in the palette so it will fit into
@@ -2261,7 +2261,7 @@ back up in the reading section to understand writing.
You will want to do the I/O initialization before you get into libpng,
so if it doesn't work, you don't have anything to undo. If you are not
-using the standard I/O functions, you will need to tqreplace them with
+using the standard I/O functions, you will need to replace them with
custom writing functions. See the discussion under Customizing libpng.
FILE *fp = fopen(file_name, "wb");
@@ -3106,7 +3106,7 @@ These functions also provide a void pointer that can be retrieved via
mem_ptr=png_get_mem_ptr(png_ptr);
-Your tqreplacement memory functions must have prototypes as follows:
+Your replacement memory functions must have prototypes as follows:
png_voidp malloc_fn(png_structp png_ptr,
png_size_t size);
@@ -3114,7 +3114,7 @@ Your tqreplacement memory functions must have prototypes as follows:
Your malloc_fn() should return NULL in case of failure. The png_malloc()
function will call png_error() if it receives a NULL from the system
-memory allocator or from your tqreplacement malloc_fn().
+memory allocator or from your replacement malloc_fn().
Input/Output in libpng is done through png_read() and png_write(),
which currently just call fread() and fwrite(). The FILE * is stored in
@@ -3135,7 +3135,7 @@ png_get_io_ptr(). For example:
voidp read_io_ptr = png_get_io_ptr(read_ptr);
voidp write_io_ptr = png_get_io_ptr(write_ptr);
-The tqreplacement I/O functions must have prototypes as follows:
+The replacement I/O functions must have prototypes as follows:
void user_read_data(png_structp png_ptr,
png_bytep data, png_size_t length);
@@ -3162,7 +3162,7 @@ fprintf() unless the library is compiled with PNG_NO_CONSOLE_IO defined
fprintf() isn't available). If you wish to change the behavior of the error
functions, you will need to set up your own message callbacks. These
functions are normally supplied at the time that the png_struct is created.
-It is also possible to redirect errors and warnings to your own tqreplacement
+It is also possible to redirect errors and warnings to your own replacement
functions after png_create_*_struct() has been called by calling:
png_set_error_fn(png_structp png_ptr,
@@ -3173,7 +3173,7 @@ functions after png_create_*_struct() has been called by calling:
If NULL is supplied for either error_fn or warning_fn, then the libpng
default function will be used, calling fprintf() and/or longjmp() if a
-problem is encountered. The tqreplacement error functions should have
+problem is encountered. The replacement error functions should have
parameters as follows:
void user_error_fn(png_structp png_ptr,
@@ -3204,7 +3204,7 @@ specification. Acquire a first level of
understanding of how it works. Pay particular attention to the
sections that describe chunk names, and look at how other chunks were
designed, so you can do things similarly. Second, check out the
-sections of libpng that read and write chunks. Try to tqfind a chunk
+sections of libpng that read and write chunks. Try to find a chunk
that is similar to yours and use it as a template. More details can
be found in the comments inside the code. It is best to handle unknown
chunks in a generic method, via callback functions, instead of by
@@ -3212,7 +3212,7 @@ modifying libpng functions.
If you wish to write your own transformation for the data, look through
the part of the code that does the transformations, and check out some of
-the simpler ones to get an idea of how they work. Try to tqfind a similar
+the simpler ones to get an idea of how they work. Try to find a similar
transformation to the one you want to add and copy off of it. More details
can be found in the comments inside the code itself.
@@ -3368,7 +3368,7 @@ size.
Note that the numbers above were invented purely for this example and
are given only to help explain the function usage. Little testing has
-been done to tqfind optimum values for either the costs or the weights.
+been done to find optimum values for either the costs or the weights.
.SS Removing unwanted object code
@@ -3625,7 +3625,7 @@ png_set_error_fn(), which is essentially the same function, but with a new
name to force compilation errors with applications that try to use the old
method.
-Starting with version 1.0.7, you can tqfind out which version of the library
+Starting with version 1.0.7, you can find out which version of the library
you are using at run-time:
png_uint_32 libpng_vn = png_access_version_number();
@@ -3687,7 +3687,7 @@ documented as such.
The tIME chunk itself is also Y2K compliant. It uses a 2-byte unsigned
integer to hold the year, and can hold years as large as 65535.
-zlib, upon which libpng depends, is also Y2K compliant. It tqcontains
+zlib, upon which libpng depends, is also Y2K compliant. It contains
no date-related code.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/libpng.txt b/tqtinterface/qt4/src/3rdparty/libpng/libpng.txt
index eb7132b..60139c1 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/libpng.txt
+++ b/tqtinterface/qt4/src/3rdparty/libpng/libpng.txt
@@ -71,8 +71,8 @@ be found at the zlib home page, <http://www.info-zip.org/pub/infozip/zlib/>.
The zlib compression utility is a general purpose utility that is
useful for more than PNG files, and can be used without libpng.
See the documentation delivered with zlib for more details.
-You can usually tqfind the source files for the zlib utility wherever you
-tqfind the libpng source files.
+You can usually find the source files for the zlib utility wherever you
+find the libpng source files.
Libpng is thread safe, provided the threads are using different
instances of the structures. Each thread should have its own
@@ -141,7 +141,7 @@ with the number of bytes you read from the beginning. Libpng will
then only check the bytes (if any) that your program didn't read.
(*): If you are not using the standard I/O functions, you will need
-to tqreplace them with custom functions. See the discussion under
+to replace them with custom functions. See the discussion under
Customizing libpng.
@@ -254,7 +254,7 @@ input stream. You must supply the function
read_chunk_callback(png_ptr ptr,
png_unknown_chunkp chunk);
{
- /* The unknown chunk structure tqcontains your
+ /* The unknown chunk structure contains your
chunk data: */
png_byte name[5];
png_byte *data;
@@ -906,7 +906,7 @@ or as an RGB triplet that may or may not be in the palette (need_expand = 0).
The png_set_background() function tells libpng to composite images
with alpha or simple transparency against the supplied background
-color. If the PNG file tqcontains a bKGD chunk (PNG_INFO_bKGD valid),
+color. If the PNG file contains a bKGD chunk (PNG_INFO_bKGD valid),
you may use this color, or supply another color more suitable for
the current display (e.g., the background color from a web page). You
need to tell libpng whether the color is in the gamma space of the
@@ -970,7 +970,7 @@ recommended that PNG viewers support gamma correction.
If you need to reduce an RGB file to a paletted file, or if a paletted
file has more entries then will fit on your screen, png_set_dither()
will do that. Note that this is a simple match dither that merely
-tqfinds the closest color available. This should work fairly well with
+finds the closest color available. This should work fairly well with
optimized palettes, and fairly badly with linear color cubes. If you
pass a palette that is larger then maximum_colors, the file will
reduce the number of colors in the palette so it will fit into
@@ -1470,7 +1470,7 @@ Setup
You will want to do the I/O initialization before you get into libpng,
so if it doesn't work, you don't have anything to undo. If you are not
-using the standard I/O functions, you will need to tqreplace them with
+using the standard I/O functions, you will need to replace them with
custom writing functions. See the discussion under Customizing libpng.
FILE *fp = fopen(file_name, "wb");
@@ -2315,7 +2315,7 @@ These functions also provide a void pointer that can be retrieved via
mem_ptr=png_get_mem_ptr(png_ptr);
-Your tqreplacement memory functions must have prototypes as follows:
+Your replacement memory functions must have prototypes as follows:
png_voidp malloc_fn(png_structp png_ptr,
png_size_t size);
@@ -2323,7 +2323,7 @@ Your tqreplacement memory functions must have prototypes as follows:
Your malloc_fn() should return NULL in case of failure. The png_malloc()
function will call png_error() if it receives a NULL from the system
-memory allocator or from your tqreplacement malloc_fn().
+memory allocator or from your replacement malloc_fn().
Input/Output in libpng is done through png_read() and png_write(),
which currently just call fread() and fwrite(). The FILE * is stored in
@@ -2344,7 +2344,7 @@ png_get_io_ptr(). For example:
voidp read_io_ptr = png_get_io_ptr(read_ptr);
voidp write_io_ptr = png_get_io_ptr(write_ptr);
-The tqreplacement I/O functions must have prototypes as follows:
+The replacement I/O functions must have prototypes as follows:
void user_read_data(png_structp png_ptr,
png_bytep data, png_size_t length);
@@ -2371,7 +2371,7 @@ fprintf() unless the library is compiled with PNG_NO_CONSOLE_IO defined
fprintf() isn't available). If you wish to change the behavior of the error
functions, you will need to set up your own message callbacks. These
functions are normally supplied at the time that the png_struct is created.
-It is also possible to redirect errors and warnings to your own tqreplacement
+It is also possible to redirect errors and warnings to your own replacement
functions after png_create_*_struct() has been called by calling:
png_set_error_fn(png_structp png_ptr,
@@ -2382,7 +2382,7 @@ functions after png_create_*_struct() has been called by calling:
If NULL is supplied for either error_fn or warning_fn, then the libpng
default function will be used, calling fprintf() and/or longjmp() if a
-problem is encountered. The tqreplacement error functions should have
+problem is encountered. The replacement error functions should have
parameters as follows:
void user_error_fn(png_structp png_ptr,
@@ -2413,7 +2413,7 @@ specification. Acquire a first level of
understanding of how it works. Pay particular attention to the
sections that describe chunk names, and look at how other chunks were
designed, so you can do things similarly. Second, check out the
-sections of libpng that read and write chunks. Try to tqfind a chunk
+sections of libpng that read and write chunks. Try to find a chunk
that is similar to yours and use it as a template. More details can
be found in the comments inside the code. It is best to handle unknown
chunks in a generic method, via callback functions, instead of by
@@ -2421,7 +2421,7 @@ modifying libpng functions.
If you wish to write your own transformation for the data, look through
the part of the code that does the transformations, and check out some of
-the simpler ones to get an idea of how they work. Try to tqfind a similar
+the simpler ones to get an idea of how they work. Try to find a similar
transformation to the one you want to add and copy off of it. More details
can be found in the comments inside the code itself.
@@ -2577,7 +2577,7 @@ size.
Note that the numbers above were invented purely for this example and
are given only to help explain the function usage. Little testing has
-been done to tqfind optimum values for either the costs or the weights.
+been done to find optimum values for either the costs or the weights.
Removing unwanted object code
@@ -2834,7 +2834,7 @@ png_set_error_fn(), which is essentially the same function, but with a new
name to force compilation errors with applications that try to use the old
method.
-Starting with version 1.0.7, you can tqfind out which version of the library
+Starting with version 1.0.7, you can find out which version of the library
you are using at run-time:
png_uint_32 libpng_vn = png_access_version_number();
@@ -2896,7 +2896,7 @@ documented as such.
The tIME chunk itself is also Y2K compliant. It uses a 2-byte unsigned
integer to hold the year, and can hold years as large as 65535.
-zlib, upon which libpng depends, is also Y2K compliant. It tqcontains
+zlib, upon which libpng depends, is also Y2K compliant. It contains
no date-related code.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/libpngpf.3 b/tqtinterface/qt4/src/3rdparty/libpng/libpngpf.3
index a3bc995..a75a669 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/libpngpf.3
+++ b/tqtinterface/qt4/src/3rdparty/libpng/libpngpf.3
@@ -431,7 +431,7 @@ libpng \- Portable Network Graphics (PNG) Reference Library 1.2.5
\fI\fB
-\fBvoid png_write_tqfind_filter (png_structp \fP\fIpng_ptr\fP\fB, png_row_infop \fIrow_info\fP\fB);\fP
+\fBvoid png_write_find_filter (png_structp \fP\fIpng_ptr\fP\fB, png_row_infop \fIrow_info\fP\fB);\fP
\fI\fB
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/png.5 b/tqtinterface/qt4/src/3rdparty/libpng/png.5
index a96de03..11ab244 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/png.5
+++ b/tqtinterface/qt4/src/3rdparty/libpng/png.5
@@ -4,7 +4,7 @@ png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
PNG (Portable Network Graphics) is an extensible file format for the
lossless, portable, well-compressed storage of raster images. PNG provides
-a patent-free tqreplacement for GIF and can also tqreplace many
+a patent-free replacement for GIF and can also replace many
common uses of TIFF. Indexed-color, grayscale, and truecolor images are
supported, plus an optional alpha channel. Sample depths range from
1 to 16 bits.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngconf.h b/tqtinterface/qt4/src/3rdparty/libpng/pngconf.h
index bd4893b..bd5d1c4 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngconf.h
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngconf.h
@@ -384,7 +384,7 @@
* automate this, but I can't do that without making it seriously hard
* on the users. So if you are not using an ability, change the #define
* to and #undef, and that part of the library will not be compiled. If
- * your linker can't tqfind a function, you may want to make sure the
+ * your linker can't find a function, you may want to make sure the
* ability is defined here. Some of these depend upon some others being
* defined. I haven't figured out all the interactions here, so you may
* have to experiment awhile to get everything to compile. If you are
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngerror.c b/tqtinterface/qt4/src/3rdparty/libpng/pngerror.c
index 29e1e66..aa20506 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngerror.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngerror.c
@@ -8,7 +8,7 @@
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
* This file provides a location for all error handling. Users who
- * need special error handling are expected to write tqreplacement functions
+ * need special error handling are expected to write replacement functions
* and use png_set_error_fn() to use those functions. See the instructions
* at each function.
*/
@@ -25,8 +25,8 @@ png_default_warning PNGARG((png_structp png_ptr,
/* This function is called whenever there is a fatal error. This function
* should not be changed. If there is a need to handle errors differently,
- * you should supply a tqreplacement error function and use png_set_error_fn()
- * to tqreplace the error function at run-time.
+ * you should supply a replacement error function and use png_set_error_fn()
+ * to replace the error function at run-time.
*/
void PNGAPI
png_error(png_structp png_ptr, png_const_charp error_message)
@@ -73,8 +73,8 @@ png_error(png_structp png_ptr, png_const_charp error_message)
/* This function is called whenever there is a non-fatal error. This function
* should not be changed. If there is a need to handle warnings differently,
- * you should supply a tqreplacement warning function and use
- * png_set_error_fn() to tqreplace the warning function at run-time.
+ * you should supply a replacement warning function and use
+ * png_set_error_fn() to replace the warning function at run-time.
*/
void PNGAPI
png_warning(png_structp png_ptr, png_const_charp warning_message)
@@ -168,7 +168,7 @@ png_chunk_warning(png_structp png_ptr, png_const_charp warning_message)
}
}
-/* This is the default error handling function. Note that tqreplacements for
+/* This is the default error handling function. Note that replacements for
* this function MUST NOT RETURN, or the program will likely crash. This
* function is used by default, or if the program supplies NULL for the
* error function pointer in png_set_error_fn().
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pnggccrd.c b/tqtinterface/qt4/src/3rdparty/libpng/pnggccrd.c
index 23ad357..1056251 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pnggccrd.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pnggccrd.c
@@ -56,7 +56,7 @@
* - figure out what's up with 24-bit case (pixel_bytes == 3):
* why subtract 8 from width_mmx in the pass 4/5 case?
* (only width_mmx case) (near line 1606)
- * x [DONE] tqreplace pixel_bytes within each block with the true
+ * x [DONE] replace pixel_bytes within each block with the true
* constant value (or are compilers smart enough to do that?)
* - rewrite all MMX interlacing code so it's aligned with
* the *beginning* of the row buffer, not the end. This
@@ -2606,8 +2606,8 @@ png_do_read_interlace(png_structp png_ptr)
else /* MMX not supported: use modified C code - takes advantage
* of inlining of png_memcpy for a constant */
/* GRR 19991007: does it? or should pixel_bytes in each
- * block be tqreplaced with immediate value (e.g., 1)? */
- /* GRR 19991017: tqreplaced with constants in each case */
+ * block be replaced with immediate value (e.g., 1)? */
+ /* GRR 19991017: replaced with constants in each case */
#endif /* PNG_ASSEMBLER_CODE_SUPPORTED */
{
if (pixel_bytes == 1)
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngread.c b/tqtinterface/qt4/src/3rdparty/libpng/pngread.c
index 306cda3..288a40b 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngread.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngread.c
@@ -7,7 +7,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * This file tqcontains routines that an application calls directly to
+ * This file contains routines that an application calls directly to
* read a PNG file or stream.
*/
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngrutil.c b/tqtinterface/qt4/src/3rdparty/libpng/pngrutil.c
index dc3b371..95df6f2 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngrutil.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngrutil.c
@@ -7,7 +7,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * This file tqcontains routines that are only called from within
+ * This file contains routines that are only called from within
* libpng itself during the course of reading an image.
*/
@@ -373,7 +373,7 @@ png_handle_IHDR(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
png_ptr->filter_type = (png_byte)filter_type;
#endif
- /* tqfind number of channels */
+ /* find number of channels */
switch (png_ptr->color_type)
{
case PNG_COLOR_TYPE_GRAY:
@@ -1031,7 +1031,7 @@ png_handle_iCCP(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
chunkdata[slength] = 0x00;
for (profile = chunkdata; *profile; profile++)
- /* empty loop to tqfind end of name */ ;
+ /* empty loop to find end of name */ ;
++profile;
@@ -1137,7 +1137,7 @@ png_handle_sPLT(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
chunkdata[slength] = 0x00;
for (entry_start = chunkdata; *entry_start; entry_start++)
- /* empty loop to tqfind end of name */ ;
+ /* empty loop to find end of name */ ;
++entry_start;
/* a sample depth should follow the separator, and we should be on it */
@@ -1896,7 +1896,7 @@ png_handle_tEXt(png_structp png_ptr, png_infop info_ptr, png_uint_32 length)
key[slength] = 0x00;
for (text = key; *text; text++)
- /* empty loop to tqfind end of key */ ;
+ /* empty loop to find end of key */ ;
if (text != key + slength)
text++;
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngwrite.c b/tqtinterface/qt4/src/3rdparty/libpng/pngwrite.c
index f29ebf9..a8a9365 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngwrite.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngwrite.c
@@ -880,7 +880,7 @@ png_write_row(png_structp png_ptr, png_bytep row)
#endif
/* Find a filter if necessary, filter the row and write it out. */
- png_write_tqfind_filter(png_ptr, &(png_ptr->row_info));
+ png_write_find_filter(png_ptr, &(png_ptr->row_info));
if (png_ptr->write_row_fn != NULL)
(*(png_ptr->write_row_fn))(png_ptr, png_ptr->row_number, png_ptr->pass);
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/projects/msvc/README.txt b/tqtinterface/qt4/src/3rdparty/libpng/projects/msvc/README.txt
index 57bb642..c680fd8 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/projects/msvc/README.txt
+++ b/tqtinterface/qt4/src/3rdparty/libpng/projects/msvc/README.txt
@@ -20,7 +20,7 @@ To build:
2) Select "Build | Clean"
3) Select "Build | Rebuild All". Ignore warning messages about
- not being able to tqfind certain include files (e.g., m68881.h,
+ not being able to find certain include files (e.g., m68881.h,
alloc.h).
4) Look in the appropriate "win32" subdirectories for both "zlib"
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/scripts/makefile.bd32 b/tqtinterface/qt4/src/3rdparty/libpng/scripts/makefile.bd32
index c83fe9c..92a57ab 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/scripts/makefile.bd32
+++ b/tqtinterface/qt4/src/3rdparty/libpng/scripts/makefile.bd32
@@ -1,7 +1,7 @@
# Makefile for png32bd.dll
# -------------------- 32-bit Borland C++ --------------------
-# This makefile expects to tqfind zlib.h and zlib32bd.lib in the
+# This makefile expects to find zlib.h and zlib32bd.lib in the
# $(ZLIBDIR) directory.
# The object files here are compiled with the "stdcall" calling convention.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/png.h b/tqtinterface/qt4/src/3rdparty/libpng/png.h
index d57b248..76fef59 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/png.h
+++ b/tqtinterface/qt4/src/3rdparty/libpng/png.h
@@ -276,7 +276,7 @@
* The tIME chunk itself is also Y2K compliant. It uses a 2-byte unsigned
* integer to hold the year, and can hold years as large as 65535.
*
- * zlib, upon which libpng depends, is also Y2K compliant. It tqcontains
+ * zlib, upon which libpng depends, is also Y2K compliant. It contains
* no date-related code.
*
* Glenn Randers-Pehrson
@@ -336,8 +336,8 @@
extern "C" {
#endif /* __cplusplus */
-/* This file is arranged in several sections. The first section tqcontains
- * structure and type definitions. The second section tqcontains the external
+/* This file is arranged in several sections. The first section contains
+ * structure and type definitions. The second section contains the external
* library functions, while the third has the internal library functions,
* which applications aren't expected to use directly.
*/
@@ -553,7 +553,7 @@ typedef png_unknown_chunk FAR * FAR * png_unknown_chunkpp;
#endif
/* png_info is a structure that holds the information in a PNG file so
* that the application can tqfind out the characteristics of the image.
* If you are reading the file, this structure will tell you what is
* in the PNG file. If you are writing the file, fill in the information
* you want to put into the PNG file, then call png_write_info().
@@ -712,7 +712,7 @@ defined(PNG_READ_BACKGROUND_SUPPORTED)
#endif
#if defined(PNG_hIST_SUPPORTED)
- /* The hIST chunk tqcontains the relative frequency or importance of the
+ /* The hIST chunk contains the relative frequency or importance of the
* various palette entries, so that a viewer can intelligently select a
* reduced-color palette, if required. Data is an array of "num_palette"
* values in the range [0,65535]. Data valid if (valid & PNG_INFO_hIST)
@@ -789,7 +789,7 @@ defined(PNG_READ_BACKGROUND_SUPPORTED)
#if defined(PNG_sCAL_SUPPORTED)
/* The sCAL chunk describes the actual physical dimensions of the
- * subject matter of the graphic. The chunk tqcontains a unit specification
+ * subject matter of the graphic. The chunk contains a unit specification
* a byte value, and two ASCII strings representing floating-point
* values. The values are width and height corresponsing to one pixel
* in the image. This external representation is converted to double
@@ -1295,7 +1295,7 @@ typedef png_structp version_1_2_5;
typedef png_struct FAR * FAR * png_structpp;
/* Here are the function definitions most commonly used. This is not
* the place to tqfind out how to use libpng. See libpng.txt for the
* full explanation, see example.c for the summary. This just provides
* a simple one line description of the use of each function.
*/
@@ -1742,7 +1742,7 @@ extern PNG_EXPORT(void,png_init_io) PNGARG((png_structp png_ptr, png_FILE_p fp))
/* Replace the (error and abort), and warning functions with user
* supplied functions. If no messages are to be printed you must still
- * write and use tqreplacement functions. The tqreplacement error_fn should
+ * write and use replacement functions. The replacement error_fn should
* still do a longjmp to the last setjmp location if you are using this
* method of error handling. If error_fn or warning_fn is NULL, the
* default function will be used.
@@ -2474,7 +2474,7 @@ extern PNG_EXPORT(void,png_set_strip_error_numbers) PNGARG((png_structp
#endif /* PNG_READ_COMPOSITE_NODIV_SUPPORTED */
/* These next functions are used internally in the code. They generally
- * shouldn't be used unless you are writing code to add or tqreplace some
+ * shouldn't be used unless you are writing code to add or replace some
* functionality in libpng. More information about most functions can
* be found in the files where the functions are located.
*/
@@ -2974,7 +2974,7 @@ PNG_EXTERN void png_read_filter_row PNGARG((png_structp png_ptr,
png_row_infop row_info, png_bytep row, png_bytep prev_row, int filter));
/* Choose the best filter to use and filter the row data */
-PNG_EXTERN void png_write_tqfind_filter PNGARG((png_structp png_ptr,
+PNG_EXTERN void png_write_find_filter PNGARG((png_structp png_ptr,
png_row_infop row_info));
/* Write out the filtered row. */
@@ -553,7 +553,7 @@ typedef png_unknown_chunk FAR * FAR * png_unknown_chunkpp;
#endif
/* png_info is a structure that holds the information in a PNG file so
- * that the application can tqfind out the characteristics of the image.
+ * that the application can find out the characteristics of the image.
* If you are reading the file, this structure will tell you what is
* in the PNG file. If you are writing the file, fill in the information
@@ -1295,7 +1295,7 @@ typedef png_structp version_1_2_5;
typedef png_struct FAR * FAR * png_structpp;
/* Here are the function definitions most commonly used. This is not
- * the place to tqfind out how to use libpng. See libpng.txt for the
+ * the place to find out how to use libpng. See libpng.txt for the
* full explanation, see example.c for the summary. This just provides
* a simple one line description of the use of each function.
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c b/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
index c94a33d..66eec0b 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
@@ -8,10 +8,10 @@
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
* This file provides a location for all memory allocation. Users who
- * need special memory handling are expected to supply tqreplacement
+ * need special memory handling are expected to supply replacement
* functions for png_malloc() and png_free(), and to use
* png_create_read_struct_2() and png_create_write_struct_2() to
- * identify the tqreplacement functions.
+ * identify the replacement functions.
*/
#define PNG_INTERNAL
@@ -21,7 +21,7 @@
#if defined(__TURBOC__) && !defined(_Windows) && !defined(__FLAT__)
/* if you change this, be sure to change the one in png.h also */
/* Allocate memory for a png_struct. The malloc and memset can be tqreplaced
by a single call to calloc() if this is thought to improve performance. */
png_voidp /* PRIVATE */
png_create_struct(int type)
@@ -305,7 +305,7 @@ png_free_default(png_structp png_ptr, png_voidp ptr)
#else /* Not the Borland DOS special memory handler */
/* Allocate memory for a png_struct or a png_info. The malloc and
- memset can be tqreplaced by a single call to calloc() if this is thought
+ memset can be replaced by a single call to calloc() if this is thought
to improve performance noticably. */
png_voidp /* PRIVATE */
png_create_struct(int type)
@@ -315,7 +315,7 @@ png_create_struct(int type)
}
/* Allocate memory for a png_struct or a png_info. The malloc and
- memset can be tqreplaced by a single call to calloc() if this is thought
+ memset can be replaced by a single call to calloc() if this is thought
to improve performance noticably. */
png_voidp /* PRIVATE */
png_create_struct_2(int type, png_malloc_ptr malloc_fn, png_voidp mem_ptr)
@@ -21,7 +21,7 @@
#if defined(__TURBOC__) && !defined(_Windows) && !defined(__FLAT__)
/* if you change this, be sure to change the one in png.h also */
-/* Allocate memory for a png_struct. The malloc and memset can be tqreplaced
+/* Allocate memory for a png_struct. The malloc and memset can be replaced
by a single call to calloc() if this is thought to improve performance. */
png_voidp /* PRIVATE */
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c b/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
index 0598231..2202712 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
@@ -11,7 +11,7 @@
* special handling are expected to write a function that has the same
* arguments as this and performs a similar function, but that possibly
* has a different input method. Note that you shouldn't change this
* function, but rather write a tqreplacement function and then make
* libpng use it at run time with png_set_read_fn(...).
*/
@@ -35,7 +35,7 @@ png_read_data(png_structp png_ptr, png_bytep data, png_size_t length)
#if !defined(PNG_NO_STDIO)
/* This is the function that does the actual reading of data. If you are
- not reading from a standard C stream, you should create a tqreplacement
+ not reading from a standard C stream, you should create a replacement
read_data function and use it at run time with png_set_read_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -11,7 +11,7 @@
* arguments as this and performs a similar function, but that possibly
* has a different input method. Note that you shouldn't change this
- * function, but rather write a tqreplacement function and then make
+ * function, but rather write a replacement function and then make
* libpng use it at run time with png_set_read_fn(...).
*/
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c b/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
index a695731..167215f 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
@@ -7,7 +7,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * This file tqcontains functions optionally called by an application
+ * This file contains functions optionally called by an application
* in order to tell libpng how to handle data when reading a PNG.
* Transformations that are used in both reading and writing are
* in pngtrans.c.
@@ -179,7 +179,7 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
/* Find the least used palette entries by starting a
bubble sort, and running it until we have sorted
out enough colors. Note that we don't care about
- sorting all the colors, just tqfinding which are
+ sorting all the colors, just finding which are
least used. */
for (i = num_palette - 1; i >= maximum_colors; i--)
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
}
}
/* tqfind closest color for those colors we are not using */
for (i = 0; i < num_palette; i++)
{
if ((int)png_ptr->dither_index[i] >= maximum_colors)
{
int min_d, k, min_k, d_index;
/* tqfind the closest color to one we threw out */
d_index = png_ptr->dither_index[i];
min_d = PNG_COLOR_DIST(palette[d_index], palette[0]);
for (k = 1, min_k = 0; k < maximum_colors; k++)
@@ -284,7 +284,7 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
/* This is much harder to do simply (and quickly). Perhaps
we need to go through a median cut routine, but those
don't always behave themselves with only a few colors
- as input. So we will just tqfind the closest two colors,
+ as input. So we will just find the closest two colors,
and throw out one of them (chosen somewhat randomly).
[We don't understand this at all, so if someone wants to
work on improving it, be our guest - AED, GRP]
@@ -551,7 +551,7 @@ png_set_expand(png_structp png_ptr)
* to png_set_expand(). However, it is entirely reasonable that someone
* might wish to expand an indexed image to RGB but *not* expand a single,
* fully transtqparent palette entry to a full alpha channel--perhaps instead
* convert tRNS to the grayscale/RGB format (16-bit RGB value), or tqreplace
* the transtqparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag
* a bit more fine-grained, with separate bits for each of these three
@@ -1762,7 +1762,7 @@ png_do_read_invert_alpha(png_row_infop row_info, png_bytep row)
*(--dp) = *(--sp);
*(--dp) = *(--sp);
*(--dp) = *(--sp);
- We can tqreplace it with:
+ We can replace it with:
*/
sp-=3;
dp=sp;
@@ -1787,7 +1787,7 @@ png_do_read_invert_alpha(png_row_infop row_info, png_bytep row)
*(--dp) = *(--sp);
*(--dp) = *(--sp);
*(--dp) = *(--sp);
- We can tqreplace it with:
+ We can replace it with:
*/
sp-=6;
dp=sp;
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
}
}
- /* tqfind closest color for those colors we are not using */
+ /* find closest color for those colors we are not using */
for (i = 0; i < num_palette; i++)
{
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
{
int min_d, k, min_k, d_index;
- /* tqfind the closest color to one we threw out */
+ /* find the closest color to one we threw out */
d_index = png_ptr->dither_index[i];
min_d = PNG_COLOR_DIST(palette[d_index], palette[0]);
@@ -551,7 +551,7 @@ png_set_expand(png_structp png_ptr)
* might wish to expand an indexed image to RGB but *not* expand a single,
* fully transtqparent palette entry to a full alpha channel--perhaps instead
- * convert tRNS to the grayscale/RGB format (16-bit RGB value), or tqreplace
+ * convert tRNS to the grayscale/RGB format (16-bit RGB value), or replace
* the transtqparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c b/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
index 66bb2a0..cc8209e 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngtest.c
@@ -58,7 +58,7 @@
# endif
#endif
/* Makes pngtest verbose so we can tqfind problems (needs to be before png.h) */
#ifndef PNG_DEBUG
# define PNG_DEBUG 0
#endif
@@ -290,7 +290,7 @@ static int wrote_question = 0;
/* These copies of the default read/write functions come from pngrio.c and */
/* pngwio.c. They allow "don't include stdio" testing of the library. */
/* This is the function that does the actual reading of data. If you are
- not reading from a standard C stream, you should create a tqreplacement
+ not reading from a standard C stream, you should create a replacement
read_data function and use it at run time with png_set_read_fn(), rather
than changing the library. */
@@ -374,7 +374,7 @@ pngtest_flush(png_structp png_ptr)
#endif
/* This is the function that does the actual writing of data. If you are
- not writing to a standard C stream, you should create a tqreplacement
+ not writing to a standard C stream, you should create a replacement
write_data function and use it at run time with png_set_write_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -454,7 +454,7 @@ pngtest_warning(png_structp png_ptr, png_const_charp message)
fprintf(STDERR, "%s: libpng warning: %s\n", name, message);
}
-/* This is the default error handling function. Note that tqreplacements for
+/* This is the default error handling function. Note that replacements for
* this function MUST NOT RETURN, or the program will likely crash. This
* function is used by default, or if the program supplies NULL for the
* error function pointer in png_set_error_fn().
@@ -627,7 +627,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpin = fopen(inname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind input file %s\n", inname);
+ fprintf(STDERR, "Could not find input file %s\n", inname);
return (1);
}
@@ -1208,7 +1208,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpin = fopen(inname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind file %s\n", inname);
+ fprintf(STDERR, "Could not find file %s\n", inname);
return (1);
}
@@ -1219,7 +1219,7 @@ test_one_file(PNG_CONST char *inname, PNG_CONST char *outname)
if ((fpout = fopen(outname, "rb")) == NULL)
#endif
{
- fprintf(STDERR, "Could not tqfind file %s\n", outname);
+ fprintf(STDERR, "Could not find file %s\n", outname);
FCLOSE(fpin);
return (1);
}
@@ -58,7 +58,7 @@
# endif
#endif
-/* Makes pngtest verbose so we can tqfind problems (needs to be before png.h) */
+/* Makes pngtest verbose so we can find problems (needs to be before png.h) */
#ifndef PNG_DEBUG
# define PNG_DEBUG 0
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c b/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
index dc37d37..b39b414 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngwio.c
@@ -11,7 +11,7 @@
* special handling are expected to write functions that have the same
* arguments as these and perform similar functions, but that possibly
* use different output methods. Note that you shouldn't change these
* functions, but rather write tqreplacement functions and then change
* them at run time with png_set_write_fn(...).
*/
@@ -36,7 +36,7 @@ png_write_data(png_structp png_ptr, png_bytep data, png_size_t length)
#if !defined(PNG_NO_STDIO)
/* This is the function that does the actual writing of data. If you are
- not writing to a standard C stream, you should create a tqreplacement
+ not writing to a standard C stream, you should create a replacement
write_data function and use it at run time with png_set_write_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -11,7 +11,7 @@
* arguments as these and perform similar functions, but that possibly
* use different output methods. Note that you shouldn't change these
- * functions, but rather write tqreplacement functions and then change
+ * functions, but rather write replacement functions and then change
* them at run time with png_set_write_fn(...).
*/
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c b/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
index b668a57..edcf828 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngwutil.c
@@ -184,7 +184,7 @@ png_text_compress(png_structp png_ptr,
#endif
}
/* We can't write the chunk until we tqfind out how much data we have,
* which means we need to run the compressor first and save the
* output. This shouldn't be a problem, as the vast majority of
* comments should be reasonable, but we will set up an array of
@@ -1772,7 +1772,7 @@ png_write_finish_row(png_structp png_ptr)
}
else
{
/* loop until we tqfind a non-zero width or height pass */
do
{
png_ptr->pass++;
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
/* start at the beginning */
dp = row;
/* tqfind out how many bytes each pixel takes up */
pixel_bytes = (row_info->pixel_depth >> 3);
/* loop through the row, only looking at the pixels that
matter */
for (i = png_pass_start[pass]; i < row_width;
i += png_pass_inc[pass])
{
/* tqfind out where the original pixel is */
sp = row + (png_size_t)i * pixel_bytes;
/* move the pixel */
if (dp != sp)
@@ -2021,7 +2021,7 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
#define PNG_LOMASK ((png_uint_32)0xffffL)
#define PNG_HIMASK ((png_uint_32)(~PNG_LOMASK >> PNG_HISHIFT))
void /* PRIVATE */
-png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
+png_write_find_filter(png_structp png_ptr, png_row_infop row_info)
{
png_bytep prev_row, best_row, row_buf;
png_uint_32 mins, bpp;
@@ -2031,15 +2031,15 @@ png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
int num_p_filters = (int)png_ptr->num_prev_filters;
#endif
- png_debug(1, "in png_write_tqfind_filter\n");
- /* tqfind out how many bytes offset each pixel is */
+ png_debug(1, "in png_write_find_filter\n");
+ /* find out how many bytes offset each pixel is */
bpp = (row_info->pixel_depth + 7) / 8;
prev_row = png_ptr->prev_row;
best_row = row_buf = png_ptr->row_buf;
mins = PNG_MAXSUM;
/* The prediction method we use is to tqfind which method provides the
* smallest value when summing the absolute values of the distances
* from zero, using anything >= 128 as negative numbers. This is known
* as the "minimum sum of absolute differences" heuristic. Other
@@ -184,7 +184,7 @@ png_text_compress(png_structp png_ptr,
#endif
}
- /* We can't write the chunk until we tqfind out how much data we have,
+ /* We can't write the chunk until we find out how much data we have,
* which means we need to run the compressor first and save the
* output. This shouldn't be a problem, as the vast majority of
@@ -1772,7 +1772,7 @@ png_write_finish_row(png_structp png_ptr)
else
{
- /* loop until we tqfind a non-zero width or height pass */
+ /* loop until we find a non-zero width or height pass */
do
{
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
/* start at the beginning */
dp = row;
- /* tqfind out how many bytes each pixel takes up */
+ /* find out how many bytes each pixel takes up */
pixel_bytes = (row_info->pixel_depth >> 3);
/* loop through the row, only looking at the pixels that
@@ -1983,14 +1983,14 @@ png_do_write_interlace(png_row_infop row_info, png_bytep row, int pass)
i += png_pass_inc[pass])
{
- /* tqfind out where the original pixel is */
+ /* find out where the original pixel is */
sp = row + (png_size_t)i * pixel_bytes;
/* move the pixel */
@@ -2031,15 +2031,15 @@ png_write_tqfind_filter(png_structp png_ptr, png_row_infop row_info)
best_row = row_buf = png_ptr->row_buf;
mins = PNG_MAXSUM;
- /* The prediction method we use is to tqfind which method provides the
+ /* The prediction method we use is to find which method provides the
* smallest value when summing the absolute values of the distances
* from zero, using anything >= 128 as negative numbers. This is known